@@ -6,7 +6,7 @@ use strict;
 use warnings;
 use English qw< -no_match_vars >;
 use Exporter 'import';
-our $VERSION = '0.727001';
+our $VERSION = '0.729';
 
 use Log::Log4perl::Tiny qw< :easy :dead_if_first >;
 
@@ -19,6 +19,7 @@ our @EXPORT_OK = qw<
   metadata
   normalize_args
   normalize_filename
+  pump
   read_file
   read_file_maybe
   resolve_module
@@ -26,6 +27,7 @@ our @EXPORT_OK = qw<
   sprintffy
   test_all_equal
   traverse
+  trim
   tube
   unzip
 >;
@@ -182,10 +184,7 @@ sub generalized_hashy {
 } ## end sub generalized_hashy
 
 sub load_module {
-   my $module = resolve_module(@_);
-   (my $packfile = $module . '.pm') =~ s{::}{/}gmxs;
-   require $packfile;
-   return $module;
+   return _load_module(resolve_module(@_));
 } ## end sub load_module
 
 sub load_sub {
@@ -267,11 +266,31 @@ sub normalize_filename {
    return $filename;
 } ## end sub normalize_filename
 
+sub pump {
+   my ($iterator, $sink) = @_;
+   if ($sink) {
+      while (my @items = $iterator->()) {
+         $sink->(@items);
+      }
+      return;
+   }
+   my $wa = wantarray();
+   if (! defined $wa) {
+      while (my @items = $iterator->()) {}
+      return;
+   }
+   my @records;
+   while (my @items = $iterator->()) {
+      push @records, @items;
+   }
+   return $wa ? @records : \@records;
+}
+
 sub read_file {
    my %args = normalize_args(
       @_,
       [
-         {binmode  => ':encoding(UTF-8)'},
+         {binmode => ':encoding(UTF-8)'},
          'filename',    # default key for "straight" unnamed parameter
       ]
    );
@@ -405,6 +424,10 @@ sub traverse {
    return $data;
 } ## end sub traverse
 
+sub trim {
+   s{\A\s+|\s+\z}{}gmxs for @_;
+}
+
 sub tube {
    my $locator = shift;
    return load_sub($locator)->(@_);
